@@ -1,4 +1,4 @@
-package NKTI::general::dbconnect;
+package NKTI::general::connection::mysql;
 
 use strict;
 use warnings;
@@ -7,13 +7,13 @@ use DBI;
 
 # Define Version :
 # ----------------------------------------------------------------
-our $VERSION = '0.07';
+our $VERSION = '0.08';
 
 # Create Module for Connection MySQL Database :
 # ------------------------------------------------------------------------
 # Module for MySQL Database Connection.
 #
-=head1 MODULE connection()
+=head1 MODULE connect()
 
     Parameter Modul :
     ----------------------------------------
